==> elastic-enterprise-search-7.13.0.tar.gz: elastic-enterprise-search-7.13.0/README.md <==
<p align="center">
  <a href="https://github.com/elastic/enterprise-search-python">
    <img src="https://raw.githubusercontent.com/elastic/enterprise-search-python/master/assets/elastic-enterprise-search-logo.png" width="70%" alt="Elastic Enterprise Search" />
  </a>
</p>
<p align="center">
<a href="https://pypi.org/project/elastic-enterprise-search"><img src="https://img.shields.io/pypi/v/elastic-enterprise-search" alt="PyPI Version"></a>
<a href="https://pypi.org/project/elastic-enterprise-search"><img src="https://img.shields.io/badge/python-2.7%20%7C%203.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-blue" alt="Supported Python Versions"></a>
<a href="https://pepy.tech/project/elastic-enterprise-search"><img src="https://pepy.tech/badge/elastic-enterprise-search" alt="Downloads"></a>
<a href="https://github.com/elastic/enterprise-search-python/actions?query=workflow%3ACI"><img src="https://img.shields.io/github/workflow/status/elastic/enterprise-search-python/CI?label=tests" alt="GitHub Actions Status"></a>
<a href="https://clients-ci.elastic.co/view/Python/job/elastic+enterprise-search-python+master"><img src="https://clients-ci.elastic.co/view/Python/job/elastic+enterprise-search-python+master/badge/icon?subject=intergration" alt="Jenkins Status"></a>
</p>

Official Python client for Elastic Enterprise Search, App Search, and Workplace Search

## Installation

The package can be installed from [PyPI](https://pypi.org/project/elastic-enterprise-search):

```bash
$ python -m pip install elastic-enterprise-search
```

The version follows the Elastic Stack version so `7.11` is compatible
with Enterprise Search released in Elastic Stack 7.11.

## Documentation

[See the documentation](https://www.elastic.co/guide/en/enterprise-search-clients/python/current/index.html) for how to get started,
compatibility info, configuring, and an API reference.

## Contributing

If you'd like to make a contribution to `enterprise-search-python` we 
provide [contributing documentation](https://github.com/elastic/enterprise-search-python/tree/master/CONTRIBUTING.md)
to ensure your first contribution goes smoothly.

## License

`enterprise-search-python` is available under the Apache-2.0 license.
For more details see [LICENSE](https://github.com/elastic/enterprise-search-python/blob/master/LICENSE).

==> elastic-enterprise-search-8.3.0.tar.gz: elastic-enterprise-search-8.3.0/README.md <==
<p align="center">
  <a href="https://github.com/elastic/enterprise-search-python">
    <img src="https://raw.githubusercontent.com/elastic/enterprise-search-python/main/assets/elastic-enterprise-search-logo.png" width="70%" alt="Elastic Enterprise Search" />
  </a>
</p>
<p align="center">
<a href="https://pypi.org/project/elastic-enterprise-search"><img src="https://img.shields.io/pypi/v/elastic-enterprise-search" alt="PyPI Version"></a>
<a href="https://pypi.org/project/elastic-enterprise-search"><img src="https://img.shields.io/badge/python-2.7%20%7C%203.6%20%7C%203.7%20%7C%203.8%20%7C%203.9-blue" alt="Supported Python Versions"></a>
<a href="https://pepy.tech/project/elastic-enterprise-search"><img src="https://pepy.tech/badge/elastic-enterprise-search" alt="Downloads"></a>
<a href="https://github.com/elastic/enterprise-search-python/actions?query=workflow%3ACI"><img src="https://img.shields.io/github/workflow/status/elastic/enterprise-search-python/CI?label=tests" alt="GitHub Actions Status"></a>
<a href="https://clients-ci.elastic.co/view/Python/job/elastic+enterprise-search-python+main"><img src="https://clients-ci.elastic.co/view/Python/job/elastic+enterprise-search-python+main/badge/icon?subject=intergration" alt="Jenkins Status"></a>
</p>

Official Python client for Elastic Enterprise Search, App Search, and Workplace Search

## Installation

The package can be installed from [PyPI](https://pypi.org/project/elastic-enterprise-search):

```bash
$ python -m pip install elastic-enterprise-search
```

The version follows the Elastic Stack version so `7.11` is compatible
with Enterprise Search released in Elastic Stack 7.11.

## Documentation

[See the documentation](https://www.elastic.co/guide/en/enterprise-search-clients/python) for how to get started,
compatibility info, configuring, and an API reference.

## Contributing

If you'd like to make a contribution to `enterprise-search-python` we 
provide [contributing documentation](https://github.com/elastic/enterprise-search-python/tree/main/CONTRIBUTING.md)
to ensure your first contribution goes smoothly.

## License

`enterprise-search-python` is available under the Apache-2.0 license.
For more details see [LICENSE](https://github.com/elastic/enterprise-search-python/blob/main/LICENSE).
